{% extends "manage.html" %}

{% block title %} Quiz List {% endblock title %}

{% block script %}
<script src="{{ URL_ROOT }}/static/yaksh/js/show_quiz.js"></script>
{% endblock %}

{% block subtitle %} Quiz List {% endblock %}
{% block manage %}
{% if not quizzes and not quiz %}
<center><h5> No quizzes available. </h5></center>
<button class="btn" type="button" onClick='location.replace("{{URL_ROOT}}/exam/manage/addquiz");'>Add New Quiz</button>&nbsp;&nbsp;
{% endif %}

{# ############################################################### #}
{# This is rendered when we are just viewing exam/monitor #}
{% if quizzes %}
<form method="post" action="" name='frm'>
{% csrf_token %}

{% for quiz in quizzes %}
<input type=checkbox name='quiz' value={{quiz.id}} />&nbsp;&nbsp;<a href="{{URL_ROOT}}/exam/manage/addquiz/{{quiz.id}}/">{{ quiz.description }}</a><br>
{% endfor %}

<br><br>
<button class="btn" type="button" onClick='location.replace("{{URL_ROOT}}/exam/manage/addquiz");'>Add New Quiz</button>&nbsp;&nbsp;
<button class="btn" type="submit" name='edit' value='edit' onClick="return confirm_edit(frm);" >Edit Selected</button>&nbsp;&nbsp;
<button class="btn" type="submit" name="delete" value='delete' onClick="return confirm_delete(frm);">Delete Selected</button>
</form>
{% endif %}

{% endblock %}
