{% extends "user.html" %}


{% block subtitle %}Hello {{ user.first_name }}, welcome to your dashboard !{% endblock %}

{% block css %}
<link rel="stylesheet" href="{{ URL_ROOT }}/static/yaksh/css/question_quiz.css" type="text/css" />
{% endblock %}

{% block script %}
<script src="{{ URL_ROOT }}/static/yaksh/js/bootstrap-alert.js"></script>
<script src="{{ URL_ROOT }}/static/yaksh/js/quizzes_user.js"></script>
{% endblock %}


{% block manage %}
    {% if cannot_attempt %}
        <p>You have not passed the prerequisite & hence you cannot take the quiz.</p>
    {% endif %}
    <h4>List of quizzes availbale for you</h4>
    {% if not quizzes %}
        <h5>No active quizzes for you</h5>
    {% endif %}
    <table>
    <th>Quiz</th>
    <th>Pre requisite quiz</th>
    {% for paper in quizzes %}
        <tr>
            {% if paper in unexpired_quizzes %}
                <td>
                    <a href="{{ URL_ROOT }}/exam/intro/{{paper.id}}">{{ paper.quiz.description }}</a><br>
                </td>
            {% else %}
                <td>
                    {{ paper.quiz.description }} <span class="label important">Expired</span><br>
                </td>
            {% endif %}
            <td>
                {% if paper.quiz.prerequisite %}
                    You have to pass {{ paper.quiz.prerequisite.description }} for taking {{ paper.quiz.description }}
                {% else %}
                    No pre requisites for {{ paper.quiz.description }}
                {% endif %}
            </td>
        </tr>
    {% endfor %}
    </table>
    <hr>    
    <h4>List of quizzes taken by you so far</h4>
    {% if quizzes_taken %}
        <table class="bordered-table zebra-striped">
            <th>Quiz</th>
            <th>Result</th>
            <th>Mraks Obtained</th>
            <th>Total Marks</th>
            <th>Percentage</th>
        {% for paper in quizzes_taken %}
            <tr>
                <td>
                    {{ paper.question_paper.quiz.description }}
                </td>
                <td>
                    {% if paper.passed %}
                        <p>Pass</p>
                    {% else %}
                        <p>Fail</p>
                    {% endif %}
                </td>
                <td>
                    {{ paper.marks_obtained }}
                </td>
                <td>
                    {{ paper.question_paper.total_marks }}
                </td>
                <td>
                    {{ paper.percent }}
                </td>
            </tr>
        {% endfor %}
        </table>
    {% else %}
        <p>You have not taken any quiz yet !!</p>
    {% endif %}


{% endblock %}

