{% extends "manage.html" %}


{% block subtitle %}Design Question Paper{% endblock %}

{% block css %}
<link rel="stylesheet" href="{{ URL_ROOT }}/static/yaksh/css/question_quiz.css" type="text/css" /> 
<link rel="stylesheet" media="all" type="text/css" href="{{ URL_ROOT }}/static/yaksh/css/autotaggit.css" />
{% endblock %}
{% block script %}
<script src="/static/yaksh/js/jquery-1.4.2.min.js" type="text/javascript"></script>
<script src="{{ URL_ROOT }}/static/yaksh/js/add_questionpaper.js"></script>
{% endblock %}

{% block manage %}
<input type=hidden id="url_root" value={{ URL_ROOT }}>
<form>
{% csrf_token %}
Select mode to design Question Paper: 
<select name='mode' id='mode' onChange='javascript:load_data();'>
  <option>---------</option>
  <option>Automatic</option>
  <option>Manual</option>
</select> 
</form>

{% endblock %}
