table th, table td 
    {	
	 text-align: left;
    }

.mini-text
{
	height : 25px;
	width : 70px;
}
.select-type
{
	width : 225px;
}
.tag-text
{
    height : 30px;
    width : 290px;
}
.date-text
{
    height : 30px;
    width : 100px;
}
