.time-div
{
    background-color:black;
    padding: 8px;
    color: #5DFC0A;
    vertical-align:middle;
    width:150px;
    float:right;
    border-radius: 6px 6px 6px 6px;
}
.td1-class
{
	width:175px;	
}
.td2-class
{
	width:50px;
}
.page-header {
  height:50px;
  text-align: center;
  background-color: #f5f5f5;
  padding: 35px 20px 10px;
  margin: -20px -20px 20px;
}
#codeTextarea{
         
       }
       .textAreaWithLines{
          font-family:courier;      
          border:1px solid #eee;
          
       }
       .textAreaWithLines textarea,.textAreaWithLines div{
          border:0px;
          line-height:120%;
          font-size:12px;
       }
       .lineObj{
          color: grey;
       }

