{% extends "manage.html" %}

{% block title %} Data for user {{ data.user.get_full_name.title }} {% endblock title %}

{% block manage %}

{% block subtitle %}Data for user {{ data.user.get_full_name.title }}{% endblock %}
<form action="" method="post">
<p> 
Name: {{ data.user.get_full_name.title }} <br/>
Username: {{ data.user.username }} <br/>
{% if data.profile %}
Roll number: {{ data.profile.roll_number }} <br/>
Position: {{ data.profile.position }} <br/>
Department: {{ data.profile.department }} <br/>
Institute: {{ data.profile.institute }} <br/>
{% endif %}
Email: {{ data.user.email }} <br/>
Date joined: {{ data.user.date_joined }} <br/>
Last login: {{ data.user.last_login }} 
</p>

{% if data.papers %}
<p><a href="{{URL_ROOT}}/exam/manage/gradeuser/{{ data.user.username }}/">
    Grade/correct paper</a>
</p>

{% for paper in data.papers %}

<h2> Quiz: {{ paper.quiz.description }} </h2>

<p>
Questions correctly answered: {{ paper.get_answered_str }} <br/>
Total attempts at questions: {{ paper.answers.count }} <br/>
Marks obtained: {{ paper.get_total_marks }} <br/>
Start time: {{ paper.start_time }} <br/>
User IP address: {{ paper.user_ip }} 
</p>

{% if paper.answers.count %}
<h3> Answers </h3>
{% for question, answers in paper.get_question_answers.items %}
<p><strong> Question: {{ question.id }}. {{ question.summary }} (Points: {{ question.points }})</strong> </p>
{% if question.type == "mcq" %}
<p> Choices: 
{% for option in question.options.strip.splitlines %} {{option}}, {% endfor %}
</p>
<p>Student answer: {{ answers.0 }}</p>
{% else %}{# non-mcq questions #}
<pre> 
{% for answer in answers %}################################################################################
{{ answer.answer.strip }}
# Autocheck: {{ answer.error }}
{% endfor %}</pre>
{% endif %}
{% with answers|last as answer %}
<p><em>Marks: {{answer.marks}} </em> </p>
{% endwith %}
{% endfor %} {# for question, answers ... #}
<h3>Teacher comments: </h3>
{{ paper.comments|default:"None" }}
{% endif %} {# if paper.answers.count #}

{% endfor %} {# for paper in data.papers #}

{% endif %} {# if data.papers #}
<br />
<hr />
<a href="{{URL_ROOT}}/exam/manage/gradeuser/{{ data.user.username }}/">
    Grade/correct paper</a>
<br/>
{% if data.papers.count > 1 %}
<a href="{{URL_ROOT}}/exam/manage/monitor/">Monitor quiz</a>
{% else %}
{% with data.papers.0 as paper %}
<a href="{{URL_ROOT}}/exam/manage/monitor/{{paper.quiz.id}}/">Monitor quiz</a>
{% endwith %}
{% endif %}

{% endblock %}
