{% extends "manage.html" %}


{% block subtitle %}Edit Quiz(zes){% endblock %}

{% block css %}
<link rel="stylesheet" href="{{ URL_ROOT }}/static/yaksh/css/question_quiz.css" type="text/css" /> 
{% endblock %}

{% block script %}
<script src="{{ URL_ROOT }}/static/yaksh/js/edit_quiz.js"></script>
{% endblock %}

{% block onload %} onload = 'javascript:form_load();' {% endblock %}

{% block manage %}
<form name=frm action="{{URL_ROOT}}/exam/manage/editquiz/" method="post">
  {% csrf_token %}
  <center>
  <table class=span1>
	{% for form in forms %}
 	<tr><td><b>Start Date: <td>{{ form.start_date}} 
    <tr><td><b>Duration: <td> {{ form.duration }}<br>{{form.duration.help_text}} 
	<tr><td><b>Active: <td> {{ form.active }} 
	<tr><td><b>Description: <td> {{ form.description }}
    <tr><td><b>Passing Criteria: <td> {{ form.pass_criteria }}<br>{{form.pass_criteria.help_text}}
	<tr><td><b>Language: <td> {{ form.language }}
	<tr><td><b>Prerequisite: <td> {{ form.prerequisite }}
	<hr>
  {% endfor %}
  </table>
  </center>
{% for i in data %}
    <input type=hidden name='quizzes' value="{{ i }}" /> 
{% endfor %}
  <center><button class="btn" type="submit" name="save">Save</button>
  <button class="btn" type="button" name="button" onClick='location.replace("{{URL_ROOT}}/exam/manage/showquiz/");'>Cancel</button> </center>
</form>
{% endblock %}
