{% extends "user.html" %}


{% block subtitle %}Results{% endblock %}

{% block css %}
<link rel="stylesheet" href="{{ URL_ROOT }}/static/yaksh/css/question_quiz.css" type="text/css" />
{% endblock %}

{% block manage %}
<form action="" method="post" name=frm>
  {% csrf_token %}
  <center><table class="span6">
    <th>Quiz Description
    <th>Obtained Marks
    <th>Maximum Marks
    <th>Percentage
    {% for paper in papers %}
        <tr>
        {% for i in paper %}
            <td>{{ i }}
        {% endfor %}
        <br>
    {% endfor %}
  </table></center>
</form>
{% endblock %}

